# Description: parse a single LaTeX command
# Arguments: 'one' is a text string of length 1 of the form \foo{bar1=value1; bar2=value2}
# Value: a list with 'type' equal to the "foo" and 'options' as
#        a named list of 'value's with 'bar's as the names.
# Details: spaces are removed from names, and values are trimmed
#          $myForumula$ is converted to \\(myFormula\\)
#
parseCommand = function(one, lineNumOffset) {
  assure(length(one)==1, 333334)

  # Allow LaTeX formulas in options and convert them to MathJax
  xonex = paste0("x", one, "x")
  formulas = gregexpr("[$](.+?)[$]", xonex)[[1]]
  if (formulas[1] != -1) {
    lengths = attr(formulas, "match.length")
    for (i in length(formulas):1) {
      form = substring(xonex, formulas[i], formulas[i]+lengths[i]-1)
      form = gsub("[$](.+?)[$]", "\\\\(\\1\\\\)", form)
      form = gsub("[\\]", "\\\\\\\\", form)
      xonex = paste0(substring(xonex, 1, formulas[i]-1),
                     form,
                     substring(xonex, formulas[i]+lengths[i]))
    }
    one = substring(xonex, 2, nchar(xonex)-1)
  }
      
  # parse options to a list
  leftBrace = gregexpr("[{]", one)[[1]]
  rightBrace = gregexpr("[}]", one)[[1]]
  leftSlash = regexpr("[\\]", one)
  if (leftBrace[1] == -1 || rightBrace[1] == -1) stop("@", lineNumOffset, " no braced options in ", one)
  if (length(leftBrace) != length(rightBrace)) stop("@", lineNumOffset, " mismatched '{' and '}' ", one)
  leftBrace = leftBrace[1]
  rightBrace = rightBrace[length(rightBrace)]
  type = gsub(" ", "", substring(one, leftSlash+1, leftBrace-1))
  options = substring(one, leftBrace+1, rightBrace-1)
  if (length(options) == 0) {
    options = NULL
  } else {
    options = strsplit(options, ";")[[1]]
    options = strsplit(options, "=")
    check = sapply(options, length)
    bad = check!=2
    if (any(bad)) {
      stop("@", lineNumOffset, " (\\", type, ") option #", which(bad)[1], " is malformed")
    }
    temp = sapply(options, function(x) gsub(" ", "", x[1]))
    options = lapply(options, function(x) str_trim(x[2]))
    names(options) = temp
  }
  return(list(type=type, options=options))
}
